Module: Aws::MarketplaceDiscovery::Types
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AmazonMachineImageFulfillmentOption, AmazonMachineImageOperatingSystem, AmazonMachineImageRecommendation, ApiFulfillmentOption, AwsSupportedService, ByolPricingTerm, Category, CloudFormationFulfillmentOption, ConfigurableUpfrontPricingTerm, ConfigurableUpfrontRateCardItem, Constraints, ContainerFulfillmentOption, ContainerOperatingSystem, DataArtifact, DataExchangeFulfillmentOption, DimensionLabel, DocumentItem, Ec2ImageBuilderComponentFulfillmentOption, EksAddOnFulfillmentOption, EksAddOnOperatingSystem, FixedUpfrontPricingTerm, FreeTrialPricingTerm, FulfillmentOption, FulfillmentOptionSummary, GetListingInput, GetListingOutput, GetOfferInput, GetOfferOutput, GetOfferSetInput, GetOfferSetOutput, GetOfferTermsInput, GetOfferTermsOutput, GetProductInput, GetProductOutput, GrantItem, HelmFulfillmentOption, HelmOperatingSystem, InternalServerException, LegalTerm, ListFulfillmentOptionsInput, ListFulfillmentOptionsOutput, ListPurchaseOptionsInput, ListPurchaseOptionsOutput, ListingAssociatedEntity, ListingBadge, ListingFacet, ListingSummary, ListingSummaryAssociatedEntity, OfferAssociatedEntity, OfferInformation, OfferSetAssociatedEntity, OfferSetInformation, OfferTerm, PaymentScheduleTerm, PricingModel, PricingUnit, ProductInformation, ProfessionalServicesFulfillmentOption, PromotionalEmbeddedImage, PromotionalEmbeddedVideo, PromotionalMedia, PurchaseOptionAssociatedEntity, PurchaseOptionBadge, PurchaseOptionFilter, PurchaseOptionSummary, RateCardItem, RecurringPaymentTerm, RenewalTerm, Resource, ResourceNotFoundException, ReviewSourceSummary, ReviewSummary, SaasFulfillmentOption, SageMakerAlgorithmFulfillmentOption, SageMakerAlgorithmRecommendation, SageMakerModelFulfillmentOption, SageMakerModelRecommendation, ScheduleItem, SearchFacetsInput, SearchFacetsOutput, SearchFilter, SearchListingsInput, SearchListingsOutput, Selector, SellerEngagement, SellerInformation, SupportTerm, ThrottlingException, UsageBasedPricingTerm, UsageBasedRateCardItem, UseCase, UseCaseEntry, ValidationException, ValidityTerm, VariablePaymentTerm
Instance Attribute Summary collapse
-
#amazon_machine_image_fulfillment_option ⇒ Types::AmazonMachineImageFulfillmentOption
An Amazon Machine Image (AMI) fulfillment option for EC2 deployment.
-
#api_fulfillment_option ⇒ Types::ApiFulfillmentOption
An API-based fulfillment option for programmatic integration.
-
#byol_pricing_term ⇒ Types::ByolPricingTerm
Defines a Bring Your Own License (BYOL) pricing term, where buyers use their existing license for the product.
-
#cloud_formation_fulfillment_option ⇒ Types::CloudFormationFulfillmentOption
An AWS CloudFormation template fulfillment option for infrastructure deployment.
-
#configurable_upfront_pricing_term ⇒ Types::ConfigurableUpfrontPricingTerm
Defines a configurable upfront pricing term with selectable rate cards, where buyers choose from predefined pricing configurations.
-
#container_fulfillment_option ⇒ Types::ContainerFulfillmentOption
A container image fulfillment option for container-based deployment.
-
#data_exchange_fulfillment_option ⇒ Types::DataExchangeFulfillmentOption
An AWS Data Exchange fulfillment option for data set delivery.
-
#ec2_image_builder_component_fulfillment_option ⇒ Types::Ec2ImageBuilderComponentFulfillmentOption
An EC2 Image Builder component fulfillment option.
-
#eks_add_on_fulfillment_option ⇒ Types::EksAddOnFulfillmentOption
An Amazon EKS add-on fulfillment option.
-
#embedded_image ⇒ Types::PromotionalEmbeddedImage
An embedded promotional image for a product.
-
#embedded_video ⇒ Types::PromotionalEmbeddedVideo
An embedded promotional video for a product.
-
#fixed_upfront_pricing_term ⇒ Types::FixedUpfrontPricingTerm
Defines a fixed upfront pricing term with a pre-paid amount and granted entitlements.
-
#free_trial_pricing_term ⇒ Types::FreeTrialPricingTerm
Defines a free trial pricing term that enables customers to try the product before purchasing.
-
#helm_fulfillment_option ⇒ Types::HelmFulfillmentOption
A Helm chart fulfillment option for Kubernetes deployment.
-
#legal_term ⇒ Types::LegalTerm
Defines a legal term containing documents proposed to buyers, such as EULAs and data subscription agreements.
-
#payment_schedule_term ⇒ Types::PaymentScheduleTerm
Defines a payment schedule term with installment payments at specified dates.
-
#professional_services_fulfillment_option ⇒ Types::ProfessionalServicesFulfillmentOption
A professional services fulfillment option.
-
#recurring_payment_term ⇒ Types::RecurringPaymentTerm
Defines a recurring payment term with fixed charges at regular billing intervals.
-
#renewal_term ⇒ Types::RenewalTerm
Defines a renewal term that enables automatic agreement renewal.
-
#saas_fulfillment_option ⇒ Types::SaasFulfillmentOption
A Software as a Service (SaaS) fulfillment option.
-
#sage_maker_algorithm_fulfillment_option ⇒ Types::SageMakerAlgorithmFulfillmentOption
An Amazon SageMaker algorithm fulfillment option.
-
#sage_maker_model_fulfillment_option ⇒ Types::SageMakerModelFulfillmentOption
An Amazon SageMaker model fulfillment option.
-
#support_term ⇒ Types::SupportTerm
Defines a support term that includes the refund policy for the offer.
-
#usage_based_pricing_term ⇒ Types::UsageBasedPricingTerm
Defines a usage-based pricing term (typically pay-as-you-go), where buyers are charged based on product usage.
-
#validity_term ⇒ Types::ValidityTerm
Defines a validity term that specifies the duration or date range of an agreement.
-
#variable_payment_term ⇒ Types::VariablePaymentTerm
Defines a variable payment term with a maximum total charge amount.
Instance Attribute Details
#amazon_machine_image_fulfillment_option ⇒ Types::AmazonMachineImageFulfillmentOption
An Amazon Machine Image (AMI) fulfillment option for EC2 deployment.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#api_fulfillment_option ⇒ Types::ApiFulfillmentOption
An API-based fulfillment option for programmatic integration.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#byol_pricing_term ⇒ Types::ByolPricingTerm
Defines a Bring Your Own License (BYOL) pricing term, where buyers use their existing license for the product.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#cloud_formation_fulfillment_option ⇒ Types::CloudFormationFulfillmentOption
An AWS CloudFormation template fulfillment option for infrastructure deployment.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#configurable_upfront_pricing_term ⇒ Types::ConfigurableUpfrontPricingTerm
Defines a configurable upfront pricing term with selectable rate cards, where buyers choose from predefined pricing configurations.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#container_fulfillment_option ⇒ Types::ContainerFulfillmentOption
A container image fulfillment option for container-based deployment.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#data_exchange_fulfillment_option ⇒ Types::DataExchangeFulfillmentOption
An AWS Data Exchange fulfillment option for data set delivery.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#ec2_image_builder_component_fulfillment_option ⇒ Types::Ec2ImageBuilderComponentFulfillmentOption
An EC2 Image Builder component fulfillment option.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#eks_add_on_fulfillment_option ⇒ Types::EksAddOnFulfillmentOption
An Amazon EKS add-on fulfillment option.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#embedded_image ⇒ Types::PromotionalEmbeddedImage
An embedded promotional image for a product.
2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2042 class PromotionalMedia < Struct.new( :embedded_image, :embedded_video, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EmbeddedImage < PromotionalMedia; end class EmbeddedVideo < PromotionalMedia; end class Unknown < PromotionalMedia; end end |
#embedded_video ⇒ Types::PromotionalEmbeddedVideo
An embedded promotional video for a product.
2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2042 class PromotionalMedia < Struct.new( :embedded_image, :embedded_video, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EmbeddedImage < PromotionalMedia; end class EmbeddedVideo < PromotionalMedia; end class Unknown < PromotionalMedia; end end |
#fixed_upfront_pricing_term ⇒ Types::FixedUpfrontPricingTerm
Defines a fixed upfront pricing term with a pre-paid amount and granted entitlements.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#free_trial_pricing_term ⇒ Types::FreeTrialPricingTerm
Defines a free trial pricing term that enables customers to try the product before purchasing.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#helm_fulfillment_option ⇒ Types::HelmFulfillmentOption
A Helm chart fulfillment option for Kubernetes deployment.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#legal_term ⇒ Types::LegalTerm
Defines a legal term containing documents proposed to buyers, such as EULAs and data subscription agreements.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#payment_schedule_term ⇒ Types::PaymentScheduleTerm
Defines a payment schedule term with installment payments at specified dates.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#professional_services_fulfillment_option ⇒ Types::ProfessionalServicesFulfillmentOption
A professional services fulfillment option.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#recurring_payment_term ⇒ Types::RecurringPaymentTerm
Defines a recurring payment term with fixed charges at regular billing intervals.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#renewal_term ⇒ Types::RenewalTerm
Defines a renewal term that enables automatic agreement renewal.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#saas_fulfillment_option ⇒ Types::SaasFulfillmentOption
A Software as a Service (SaaS) fulfillment option.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#sage_maker_algorithm_fulfillment_option ⇒ Types::SageMakerAlgorithmFulfillmentOption
An Amazon SageMaker algorithm fulfillment option.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#sage_maker_model_fulfillment_option ⇒ Types::SageMakerModelFulfillmentOption
An Amazon SageMaker model fulfillment option.
789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 789 class FulfillmentOption < Struct.new( :amazon_machine_image_fulfillment_option, :api_fulfillment_option, :cloud_formation_fulfillment_option, :container_fulfillment_option, :helm_fulfillment_option, :eks_add_on_fulfillment_option, :ec2_image_builder_component_fulfillment_option, :data_exchange_fulfillment_option, :professional_services_fulfillment_option, :saas_fulfillment_option, :sage_maker_algorithm_fulfillment_option, :sage_maker_model_fulfillment_option, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AmazonMachineImageFulfillmentOption < FulfillmentOption; end class ApiFulfillmentOption < FulfillmentOption; end class CloudFormationFulfillmentOption < FulfillmentOption; end class ContainerFulfillmentOption < FulfillmentOption; end class HelmFulfillmentOption < FulfillmentOption; end class EksAddOnFulfillmentOption < FulfillmentOption; end class Ec2ImageBuilderComponentFulfillmentOption < FulfillmentOption; end class DataExchangeFulfillmentOption < FulfillmentOption; end class ProfessionalServicesFulfillmentOption < FulfillmentOption; end class SaasFulfillmentOption < FulfillmentOption; end class SageMakerAlgorithmFulfillmentOption < FulfillmentOption; end class SageMakerModelFulfillmentOption < FulfillmentOption; end class Unknown < FulfillmentOption; end end |
#support_term ⇒ Types::SupportTerm
Defines a support term that includes the refund policy for the offer.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#usage_based_pricing_term ⇒ Types::UsageBasedPricingTerm
Defines a usage-based pricing term (typically pay-as-you-go), where buyers are charged based on product usage.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#validity_term ⇒ Types::ValidityTerm
Defines a validity term that specifies the duration or date range of an agreement.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |
#variable_payment_term ⇒ Types::VariablePaymentTerm
Defines a variable payment term with a maximum total charge amount.
1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1816 class OfferTerm < Struct.new( :byol_pricing_term, :configurable_upfront_pricing_term, :fixed_upfront_pricing_term, :free_trial_pricing_term, :legal_term, :payment_schedule_term, :recurring_payment_term, :renewal_term, :support_term, :usage_based_pricing_term, :validity_term, :variable_payment_term, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class ByolPricingTerm < OfferTerm; end class ConfigurableUpfrontPricingTerm < OfferTerm; end class FixedUpfrontPricingTerm < OfferTerm; end class FreeTrialPricingTerm < OfferTerm; end class LegalTerm < OfferTerm; end class PaymentScheduleTerm < OfferTerm; end class RecurringPaymentTerm < OfferTerm; end class RenewalTerm < OfferTerm; end class SupportTerm < OfferTerm; end class UsageBasedPricingTerm < OfferTerm; end class ValidityTerm < OfferTerm; end class VariablePaymentTerm < OfferTerm; end class Unknown < OfferTerm; end end |