Class: Aws::MarketplaceDiscovery::Types::AmazonMachineImageFulfillmentOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Describes an Amazon Machine Image (AMI) fulfillment option, including version details, supported operating systems, and recommended instance types.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fulfillment_option_display_nameString

A human-readable name for the fulfillment option type.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_idString

The unique identifier of the fulfillment option.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_nameString

The display name of the fulfillment option version.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_typeString

The category of the fulfillment option.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_versionString

The version identifier of the fulfillment option.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#operating_systemsArray<Types::AmazonMachineImageOperatingSystem>

The operating systems supported by this AMI.



69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationTypes::AmazonMachineImageRecommendation

Recommended instance types for running this AMI.



69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#release_notesString

Release notes describing changes in this version of the fulfillment option.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#usage_instructionsString

Instructions on how to deploy and use this fulfillment option.

Returns:

  • (String)


69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69

class AmazonMachineImageFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_version,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :operating_systems,
  :recommendation,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end