Class: Aws::MarketplaceDiscovery::Types::AmazonMachineImageOperatingSystem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Describes an operating system supported by an AMI fulfillment option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#operating_system_family_nameString

The operating system family, such as Linux or Windows.

Returns:

  • (String)


100
101
102
103
104
105
106
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 100

class AmazonMachineImageOperatingSystem < Struct.new(
  :operating_system_family_name,
  :operating_system_name,
  :operating_system_version)
  SENSITIVE = []
  include Aws::Structure
end

#operating_system_nameString

The specific operating system name, such as Amazon Linux 2 or Windows Server 2022.

Returns:

  • (String)


100
101
102
103
104
105
106
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 100

class AmazonMachineImageOperatingSystem < Struct.new(
  :operating_system_family_name,
  :operating_system_name,
  :operating_system_version)
  SENSITIVE = []
  include Aws::Structure
end

#operating_system_versionString

The version of the operating system.

Returns:

  • (String)


100
101
102
103
104
105
106
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 100

class AmazonMachineImageOperatingSystem < Struct.new(
  :operating_system_family_name,
  :operating_system_name,
  :operating_system_version)
  SENSITIVE = []
  include Aws::Structure
end