Class: Aws::MarketplaceDiscovery::Types::ApiFulfillmentOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Describes an API-based fulfillment option, where the product is accessed through an API integration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_supported_servicesArray<Types::AwsSupportedService>

The AWS services supported by this API integration.

Returns:



147
148
149
150
151
152
153
154
155
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147

class ApiFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :usage_instructions,
  :aws_supported_services)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_display_nameString

A human-readable name for the fulfillment option type.

Returns:

  • (String)


147
148
149
150
151
152
153
154
155
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147

class ApiFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :usage_instructions,
  :aws_supported_services)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_idString

The unique identifier of the fulfillment option.

Returns:

  • (String)


147
148
149
150
151
152
153
154
155
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147

class ApiFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :usage_instructions,
  :aws_supported_services)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_typeString

The category of the fulfillment option.

Returns:

  • (String)


147
148
149
150
151
152
153
154
155
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147

class ApiFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :usage_instructions,
  :aws_supported_services)
  SENSITIVE = []
  include Aws::Structure
end

#usage_instructionsString

Instructions on how to integrate with and use this API.

Returns:

  • (String)


147
148
149
150
151
152
153
154
155
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147

class ApiFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :usage_instructions,
  :aws_supported_services)
  SENSITIVE = []
  include Aws::Structure
end