Class: Aws::MarketplaceDiscovery::Types::ConfigurableUpfrontPricingTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a configurable upfront pricing term with selectable rate cards, where buyers choose from predefined pricing configurations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currency_codeString

Defines the currency for the prices in this term.

Returns:

  • (String)


288
289
290
291
292
293
294
295
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 288

class ConfigurableUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :rate_cards)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the term.

Returns:

  • (String)


288
289
290
291
292
293
294
295
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 288

class ConfigurableUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :rate_cards)
  SENSITIVE = []
  include Aws::Structure
end

#rate_cardsArray<Types::ConfigurableUpfrontRateCardItem>

The rate cards available for selection, each with a selector, constraints, and per-unit rates.



288
289
290
291
292
293
294
295
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 288

class ConfigurableUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :rate_cards)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:

  • (String)


288
289
290
291
292
293
294
295
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 288

class ConfigurableUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :rate_cards)
  SENSITIVE = []
  include Aws::Structure
end