Class: Aws::MarketplaceDiscovery::Types::ContainerFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::ContainerFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes a container image fulfillment option for container-based deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this container deployment.
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
-
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
-
#operating_systems ⇒ Array<Types::ContainerOperatingSystem>
The operating systems supported by this container image.
-
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
-
#usage_instructions ⇒ String
Instructions on how to deploy and use this container image.
Instance Attribute Details
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this container deployment.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#operating_systems ⇒ Array<Types::ContainerOperatingSystem>
The operating systems supported by this container image.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#usage_instructions ⇒ String
Instructions on how to deploy and use this container image.
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 386 class ContainerFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |