Class: Aws::MarketplaceDiscovery::Types::DataArtifact

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Describes a data artifact within a Data Exchange fulfillment option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_classificationString

The classification of sensitive data contained in the dataset.

Returns:

  • (String)


440
441
442
443
444
445
446
447
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 440

class DataArtifact < Struct.new(
  :description,
  :resource_arn,
  :resource_type,
  :data_classification)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the data artifact.

Returns:

  • (String)


440
441
442
443
444
445
446
447
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 440

class DataArtifact < Struct.new(
  :description,
  :resource_arn,
  :resource_type,
  :data_classification)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the data artifact.

Returns:

  • (String)


440
441
442
443
444
445
446
447
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 440

class DataArtifact < Struct.new(
  :description,
  :resource_arn,
  :resource_type,
  :data_classification)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the data artifact resource.

Returns:

  • (String)


440
441
442
443
444
445
446
447
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 440

class DataArtifact < Struct.new(
  :description,
  :resource_arn,
  :resource_type,
  :data_classification)
  SENSITIVE = []
  include Aws::Structure
end