Class: Aws::MarketplaceDiscovery::Types::DataExchangeFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::DataExchangeFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes an AWS Data Exchange fulfillment option for data set delivery.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_artifacts ⇒ Array<Types::DataArtifact>
The data artifacts included in this Data Exchange fulfillment option.
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
Instance Attribute Details
#data_artifacts ⇒ Array<Types::DataArtifact>
The data artifacts included in this Data Exchange fulfillment option.
471 472 473 474 475 476 477 478 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 471 class DataExchangeFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :data_artifacts) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
471 472 473 474 475 476 477 478 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 471 class DataExchangeFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :data_artifacts) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
471 472 473 474 475 476 477 478 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 471 class DataExchangeFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :data_artifacts) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
471 472 473 474 475 476 477 478 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 471 class DataExchangeFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :data_artifacts) SENSITIVE = [] include Aws::Structure end |