Class: Aws::MarketplaceDiscovery::Types::DimensionLabel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A label used to group or categorize pricing dimensions, such as by region or SageMaker option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_nameString

The human-readable display name of the label.

Returns:

  • (String)


498
499
500
501
502
503
504
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 498

class DimensionLabel < Struct.new(
  :label_type,
  :label_value,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#label_typeString

The type of the dimension label, such as Region or SagemakerOption.

Returns:

  • (String)


498
499
500
501
502
503
504
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 498

class DimensionLabel < Struct.new(
  :label_type,
  :label_value,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#label_valueString

The value used to group dimensions together.

Returns:

  • (String)


498
499
500
501
502
503
504
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 498

class DimensionLabel < Struct.new(
  :label_type,
  :label_value,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end