Class: Aws::MarketplaceDiscovery::Types::DocumentItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A legal document associated with a legal term, such as a EULA or data subscription agreement.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The category of the legal document, such as StandardEula or CustomEula.

Returns:

  • (String)


524
525
526
527
528
529
530
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 524

class DocumentItem < Struct.new(
  :type,
  :url,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#urlString

The URL where the legal document can be accessed.

Returns:

  • (String)


524
525
526
527
528
529
530
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 524

class DocumentItem < Struct.new(
  :type,
  :url,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the standard contract, if applicable.

Returns:

  • (String)


524
525
526
527
528
529
530
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 524

class DocumentItem < Struct.new(
  :type,
  :url,
  :version)
  SENSITIVE = []
  include Aws::Structure
end