Class: Aws::MarketplaceDiscovery::Types::Ec2ImageBuilderComponentFulfillmentOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Describes an EC2 Image Builder component fulfillment option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_supported_servicesArray<Types::AwsSupportedService>

The AWS services supported by this EC2 Image Builder component.

Returns:



574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_display_nameString

A human-readable name for the fulfillment option type.

Returns:

  • (String)


574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_idString

The unique identifier of the fulfillment option.

Returns:

  • (String)


574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_nameString

The display name of the fulfillment option version.

Returns:

  • (String)


574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_typeString

The category of the fulfillment option.

Returns:

  • (String)


574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_versionString

The version identifier of the fulfillment option.

Returns:

  • (String)


574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#operating_systemsArray<Types::ContainerOperatingSystem>

The operating systems supported by this EC2 Image Builder component.



574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#release_notesString

Release notes describing changes in this version of the fulfillment option.

Returns:

  • (String)


574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#usage_instructionsString

Instructions on how to deploy and use this EC2 Image Builder component.

Returns:

  • (String)


574
575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574

class Ec2ImageBuilderComponentFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :aws_supported_services,
  :release_notes,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end