Class: Aws::MarketplaceDiscovery::Types::EksAddOnFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::EksAddOnFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes an Amazon EKS add-on fulfillment option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this EKS add-on.
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
-
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
-
#operating_systems ⇒ Array<Types::EksAddOnOperatingSystem>
The operating systems supported by this EKS add-on.
-
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
-
#usage_instructions ⇒ String
Instructions on how to deploy and use this EKS add-on.
Instance Attribute Details
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this EKS add-on.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#operating_systems ⇒ Array<Types::EksAddOnOperatingSystem>
The operating systems supported by this EKS add-on.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#usage_instructions ⇒ String
Instructions on how to deploy and use this EKS add-on.
629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 629 class EksAddOnFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |