Class: Aws::MarketplaceDiscovery::Types::FixedUpfrontPricingTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a fixed upfront pricing term with a pre-paid amount and granted entitlements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currency_codeString

Defines the currency for the prices in this term.

Returns:



707
708
709
710
711
712
713
714
715
716
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707

class FixedUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :duration,
  :price,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end

#durationString

The duration of the fixed pricing term, in ISO 8601 format.

Returns:



707
708
709
710
711
712
713
714
715
716
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707

class FixedUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :duration,
  :price,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end

#grantsArray<Types::GrantItem>

The entitlements granted to the buyer as part of this term.

Returns:



707
708
709
710
711
712
713
714
715
716
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707

class FixedUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :duration,
  :price,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the term.

Returns:



707
708
709
710
711
712
713
714
715
716
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707

class FixedUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :duration,
  :price,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end

#priceString

The price charged upfront for this term.

Returns:



707
708
709
710
711
712
713
714
715
716
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707

class FixedUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :duration,
  :price,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:



707
708
709
710
711
712
713
714
715
716
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707

class FixedUpfrontPricingTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :duration,
  :price,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end