Class: Aws::MarketplaceDiscovery::Types::FreeTrialPricingTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a free trial pricing term that enables customers to try the product before purchasing.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durationString

The duration of the free trial period.

Returns:

  • (String)


739
740
741
742
743
744
745
746
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 739

class FreeTrialPricingTerm < Struct.new(
  :id,
  :type,
  :duration,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end

#grantsArray<Types::GrantItem>

The entitlements granted to the buyer during the free trial.

Returns:



739
740
741
742
743
744
745
746
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 739

class FreeTrialPricingTerm < Struct.new(
  :id,
  :type,
  :duration,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the term.

Returns:

  • (String)


739
740
741
742
743
744
745
746
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 739

class FreeTrialPricingTerm < Struct.new(
  :id,
  :type,
  :duration,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:

  • (String)


739
740
741
742
743
744
745
746
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 739

class FreeTrialPricingTerm < Struct.new(
  :id,
  :type,
  :duration,
  :grants)
  SENSITIVE = []
  include Aws::Structure
end