Class: Aws::MarketplaceDiscovery::Types::FulfillmentOptionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A summary of a fulfillment option available for deploying or accessing a listing or product.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_nameString

The human-readable name of the fulfillment option type.

Returns:

  • (String)


851
852
853
854
855
856
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 851

class FulfillmentOptionSummary < Struct.new(
  :fulfillment_option_type,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_typeString

The machine-readable type of the fulfillment option, such as SAAS or AMAZON_MACHINE_IMAGE.

Returns:

  • (String)


851
852
853
854
855
856
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 851

class FulfillmentOptionSummary < Struct.new(
  :fulfillment_option_type,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end