Class: Aws::MarketplaceDiscovery::Types::GetOfferOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agreement_proposal_idString

An encoded string to be passed by the acceptor of the terms when creating an agreement.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#associated_entitiesArray<Types::OfferAssociatedEntity>

The products and offer sets associated with this offer.

Returns:



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#available_from_timeTime

The date and time when the offer became available to the buyer.

Returns:

  • (Time)


1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#badgesArray<Types::PurchaseOptionBadge>

Badges indicating special attributes of the offer, such as private pricing, future dated, or replacement offer.

Returns:



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#catalogString

The name of the catalog that the offer belongs to.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_timeTime

The date and time until when the offer can be procured. This value is null for offers that never expire.

Returns:

  • (Time)


1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#offer_idString

The unique identifier of the offer.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#offer_nameString

The display name of the offer. This is free-form text provided by the seller.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#pricing_modelTypes::PricingModel

The pricing model that determines how buyers are charged, such as usage-based, contract, BYOL, or free.

Returns:



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#replacement_agreement_idString

The identifier of the existing agreement that this offer would replace. Enables agreement-based offer functionality.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end

#seller_of_recordTypes::SellerInformation

The entity responsible for selling the product under this offer.



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054

class GetOfferOutput < Struct.new(
  :offer_id,
  :catalog,
  :offer_name,
  :expiration_time,
  :available_from_time,
  :seller_of_record,
  :associated_entities,
  :agreement_proposal_id,
  :replacement_agreement_id,
  :pricing_model,
  :badges)
  SENSITIVE = []
  include Aws::Structure
end