Class: Aws::MarketplaceDiscovery::Types::GetOfferSetInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::GetOfferSetInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#offer_set_id ⇒ String
The unique identifier of the offer set to retrieve.
Instance Attribute Details
#offer_set_id ⇒ String
The unique identifier of the offer set to retrieve.
1076 1077 1078 1079 1080 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1076 class GetOfferSetInput < Struct.new( :offer_set_id) SENSITIVE = [] include Aws::Structure end |