Class: Aws::MarketplaceDiscovery::Types::GetOfferSetOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#associated_entitiesArray<Types::OfferSetAssociatedEntity>

The products and offers included in this offer set.



1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end

#available_from_timeTime

The date and time when the offer set became available to the buyer.

Returns:

  • (Time)


1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end

#badgesArray<Types::PurchaseOptionBadge>

Badges indicating special attributes of the offer set, such as private pricing or future dated.

Returns:



1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end

#buyer_notesString

Detailed information about the offer set that helps buyers understand its purpose and contents.

Returns:

  • (String)


1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end

#catalogString

The name of the catalog that the offer set belongs to.

Returns:

  • (String)


1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end

#expiration_timeTime

The date and time when the offer set expires and is no longer available for procurement.

Returns:

  • (Time)


1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end

#offer_set_idString

The unique identifier of the offer set.

Returns:

  • (String)


1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end

#offer_set_nameString

The display name of the offer set.

Returns:

  • (String)


1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end

#seller_of_recordTypes::SellerInformation

The entity responsible for selling the products under this offer set.



1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1124

class GetOfferSetOutput < Struct.new(
  :offer_set_id,
  :catalog,
  :offer_set_name,
  :available_from_time,
  :expiration_time,
  :buyer_notes,
  :seller_of_record,
  :badges,
  :associated_entities)
  SENSITIVE = []
  include Aws::Structure
end