Class: Aws::MarketplaceDiscovery::Types::GetOfferTermsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results that are returned per call. You can use nextToken to get more results.

Returns:

  • (Integer)


1154
1155
1156
1157
1158
1159
1160
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1154

class GetOfferTermsInput < Struct.new(
  :offer_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page.

Returns:

  • (String)


1154
1155
1156
1157
1158
1159
1160
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1154

class GetOfferTermsInput < Struct.new(
  :offer_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#offer_idString

The unique identifier of the offer whose terms to retrieve.

Returns:

  • (String)


1154
1155
1156
1157
1158
1159
1160
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1154

class GetOfferTermsInput < Struct.new(
  :offer_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end