Class: Aws::MarketplaceDiscovery::Types::GrantItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

An entitlement granted to the buyer as part of a pricing term.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the entitlement.

Returns:

  • (String)


1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304

class GrantItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :max_quantity)
  SENSITIVE = []
  include Aws::Structure
end

#dimension_keyString

The machine-readable key identifying the entitlement dimension.

Returns:

  • (String)


1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304

class GrantItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :max_quantity)
  SENSITIVE = []
  include Aws::Structure
end

#dimension_labelsArray<Types::DimensionLabel>

Labels used to categorize this entitlement, such as by region.

Returns:



1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304

class GrantItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :max_quantity)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The human-readable name of the entitlement dimension.

Returns:

  • (String)


1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304

class GrantItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :max_quantity)
  SENSITIVE = []
  include Aws::Structure
end

#max_quantityInteger

The maximum quantity of the entitlement that can be granted.

Returns:

  • (Integer)


1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304

class GrantItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :max_quantity)
  SENSITIVE = []
  include Aws::Structure
end

#unitString

The unit of measurement for the entitlement.

Returns:

  • (String)


1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304

class GrantItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :max_quantity)
  SENSITIVE = []
  include Aws::Structure
end