Class: Aws::MarketplaceDiscovery::Types::HelmFulfillmentOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Describes a Helm chart fulfillment option for Kubernetes deployment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_supported_servicesArray<Types::AwsSupportedService>

The AWS services supported by this Helm chart deployment.

Returns:



1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_display_nameString

A human-readable name for the fulfillment option type.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_idString

The unique identifier of the fulfillment option.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_nameString

The display name of the fulfillment option version.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_typeString

The category of the fulfillment option.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_versionString

The version identifier of the fulfillment option.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#operating_systemsArray<Types::HelmOperatingSystem>

The operating systems supported by this Helm chart.

Returns:



1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#release_notesString

Release notes describing changes in this version of the fulfillment option.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end

#usage_instructionsString

Instructions on how to deploy and use this Helm chart.

Returns:

  • (String)


1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356

class HelmFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_name,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :operating_systems,
  :release_notes,
  :aws_supported_services,
  :usage_instructions)
  SENSITIVE = []
  include Aws::Structure
end