Class: Aws::MarketplaceDiscovery::Types::LegalTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a legal term containing documents proposed to buyers, such as EULAs and data subscription agreements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#documentsArray<Types::DocumentItem>

The legal documents proposed to the buyer as part of this term.

Returns:



1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1420

class LegalTerm < Struct.new(
  :id,
  :type,
  :documents)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the term.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1420

class LegalTerm < Struct.new(
  :id,
  :type,
  :documents)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:

  • (String)


1420
1421
1422
1423
1424
1425
1426
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1420

class LegalTerm < Struct.new(
  :id,
  :type,
  :documents)
  SENSITIVE = []
  include Aws::Structure
end