Class: Aws::MarketplaceDiscovery::Types::NetPaymentTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a net payment term that sets how many days after the invoice date the payment is due.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The unique identifier of the term.

Returns:

  • (String)


1698
1699
1700
1701
1702
1703
1704
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1698

class NetPaymentTerm < Struct.new(
  :id,
  :type,
  :payment_due_period)
  SENSITIVE = []
  include Aws::Structure
end

#payment_due_periodString

The duration after invoice date by which payment is due.

Returns:

  • (String)


1698
1699
1700
1701
1702
1703
1704
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1698

class NetPaymentTerm < Struct.new(
  :id,
  :type,
  :payment_due_period)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:

  • (String)


1698
1699
1700
1701
1702
1703
1704
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1698

class NetPaymentTerm < Struct.new(
  :id,
  :type,
  :payment_due_period)
  SENSITIVE = []
  include Aws::Structure
end