Class: Aws::MarketplaceDiscovery::Types::OfferAssociatedEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A product and optional offer set associated with an offer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#offer_setTypes::OfferSetInformation

Information about the offer set, if the offer is part of a bundled offer set.



1719
1720
1721
1722
1723
1724
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1719

class OfferAssociatedEntity < Struct.new(
  :product,
  :offer_set)
  SENSITIVE = []
  include Aws::Structure
end

#productTypes::ProductInformation

Information about the product associated with the offer.



1719
1720
1721
1722
1723
1724
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1719

class OfferAssociatedEntity < Struct.new(
  :product,
  :offer_set)
  SENSITIVE = []
  include Aws::Structure
end