Class: Aws::MarketplaceDiscovery::Types::OfferSetAssociatedEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A product and offer associated with an offer set.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#offerTypes::OfferInformation

Information about the offer associated with the offer set.



1763
1764
1765
1766
1767
1768
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1763

class OfferSetAssociatedEntity < Struct.new(
  :product,
  :offer)
  SENSITIVE = []
  include Aws::Structure
end

#productTypes::ProductInformation

Information about the product associated with the offer set.



1763
1764
1765
1766
1767
1768
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1763

class OfferSetAssociatedEntity < Struct.new(
  :product,
  :offer)
  SENSITIVE = []
  include Aws::Structure
end