Class: Aws::MarketplaceDiscovery::Types::OfferTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Note:

OfferTerm is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OfferTerm corresponding to the set member.

A term attached to an offer. Each element contains exactly one term type, such as a pricing term, legal term, or payment schedule term.

Defined Under Namespace

Classes: ByolPricingTerm, ConfigurableUpfrontPricingTerm, FixedUpfrontPricingTerm, FreeTrialPricingTerm, LegalTerm, NetPaymentTerm, PaymentScheduleTerm, RecurringPaymentTerm, RenewalTerm, SupportTerm, Unknown, UsageBasedPricingTerm, ValidityTerm, VariablePaymentTerm

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#byol_pricing_termTypes::ByolPricingTerm

Defines a Bring Your Own License (BYOL) pricing term, where buyers use their existing license for the product.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#configurable_upfront_pricing_termTypes::ConfigurableUpfrontPricingTerm

Defines a configurable upfront pricing term with selectable rate cards, where buyers choose from predefined pricing configurations.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#fixed_upfront_pricing_termTypes::FixedUpfrontPricingTerm

Defines a fixed upfront pricing term with a pre-paid amount and granted entitlements.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#free_trial_pricing_termTypes::FreeTrialPricingTerm

Defines a free trial pricing term that enables customers to try the product before purchasing.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

Defines a legal term containing documents proposed to buyers, such as EULAs and data subscription agreements.

Returns:



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#net_payment_termTypes::NetPaymentTerm

A net payment term.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#payment_schedule_termTypes::PaymentScheduleTerm

Defines a payment schedule term with installment payments at specified dates.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#recurring_payment_termTypes::RecurringPaymentTerm

Defines a recurring payment term with fixed charges at regular billing intervals.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#renewal_termTypes::RenewalTerm

Defines a renewal term that enables automatic agreement renewal.

Returns:



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#support_termTypes::SupportTerm

Defines a support term that includes the refund policy for the offer.

Returns:



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1860
1861
1862
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

def unknown
  @unknown
end

#usage_based_pricing_termTypes::UsageBasedPricingTerm

Defines a usage-based pricing term (typically pay-as-you-go), where buyers are charged based on product usage.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#validity_termTypes::ValidityTerm

Defines a validity term that specifies the duration or date range of an agreement.

Returns:



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end

#variable_payment_termTypes::VariablePaymentTerm

Defines a variable payment term with a maximum total charge amount.



1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1860

class OfferTerm < Struct.new(
  :byol_pricing_term,
  :configurable_upfront_pricing_term,
  :fixed_upfront_pricing_term,
  :free_trial_pricing_term,
  :legal_term,
  :payment_schedule_term,
  :recurring_payment_term,
  :renewal_term,
  :support_term,
  :usage_based_pricing_term,
  :validity_term,
  :variable_payment_term,
  :net_payment_term,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class ByolPricingTerm < OfferTerm; end
  class ConfigurableUpfrontPricingTerm < OfferTerm; end
  class FixedUpfrontPricingTerm < OfferTerm; end
  class FreeTrialPricingTerm < OfferTerm; end
  class LegalTerm < OfferTerm; end
  class PaymentScheduleTerm < OfferTerm; end
  class RecurringPaymentTerm < OfferTerm; end
  class RenewalTerm < OfferTerm; end
  class SupportTerm < OfferTerm; end
  class UsageBasedPricingTerm < OfferTerm; end
  class ValidityTerm < OfferTerm; end
  class VariablePaymentTerm < OfferTerm; end
  class NetPaymentTerm < OfferTerm; end
  class Unknown < OfferTerm; end
end