Class: Aws::MarketplaceDiscovery::Types::PaymentScheduleTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a payment schedule term with installment payments at specified dates.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currency_codeString

Defines the currency for the prices in this term.

Returns:

  • (String)


1950
1951
1952
1953
1954
1955
1956
1957
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1950

class PaymentScheduleTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the term.

Returns:

  • (String)


1950
1951
1952
1953
1954
1955
1956
1957
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1950

class PaymentScheduleTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleArray<Types::ScheduleItem>

The payment schedule installments, each with a charge date and amount.

Returns:



1950
1951
1952
1953
1954
1955
1956
1957
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1950

class PaymentScheduleTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:

  • (String)


1950
1951
1952
1953
1954
1955
1956
1957
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1950

class PaymentScheduleTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end