Class: Aws::MarketplaceDiscovery::Types::PaymentScheduleTermTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A template for the payment schedule term on the renewal offer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#scheduleArray<Types::PaymentScheduleEntry>

An ordered list of installment entries for the renewal payment schedule.

Returns:



1968
1969
1970
1971
1972
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1968

class PaymentScheduleTermTemplate < Struct.new(
  :schedule)
  SENSITIVE = []
  include Aws::Structure
end