Class: Aws::MarketplaceDiscovery::Types::PriceIncrease

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Note:

PriceIncrease is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PriceIncrease corresponding to the set member.

The pricing adjustment that applies at each renewal cycle, expressed as either a fixed percentage or a percentage range. Exactly one variant is present.

Defined Under Namespace

Classes: FixedPercentage, PercentageRange, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fixed_percentageTypes::FixedPercentage

A single fixed percentage applied uniformly at every renewal cycle.



2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2020

class PriceIncrease < Struct.new(
  :fixed_percentage,
  :percentage_range,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class FixedPercentage < PriceIncrease; end
  class PercentageRange < PriceIncrease; end
  class Unknown < PriceIncrease; end
end

#percentage_rangeTypes::PercentageRange

A percentage band with minimum, maximum, and default values that bound the price increase at each renewal cycle.



2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2020

class PriceIncrease < Struct.new(
  :fixed_percentage,
  :percentage_range,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class FixedPercentage < PriceIncrease; end
  class PercentageRange < PriceIncrease; end
  class Unknown < PriceIncrease; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2020
2021
2022
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2020

def unknown
  @unknown
end