Class: Aws::MarketplaceDiscovery::Types::PricingUnit

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A pricing unit that defines the billing dimension for a listing, such as users, hosts, bandwidth, or data.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#display_nameString

The human-readable name of the pricing unit.

Returns:

  • (String)


2066
2067
2068
2069
2070
2071
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2066

class PricingUnit < Struct.new(
  :pricing_unit_type,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#pricing_unit_typeString

The machine-readable type of the pricing unit.

Returns:

  • (String)


2066
2067
2068
2069
2070
2071
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2066

class PricingUnit < Struct.new(
  :pricing_unit_type,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end