Class: Aws::MarketplaceDiscovery::Types::PromotionalMedia

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Note:

PromotionalMedia is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PromotionalMedia corresponding to the set member.

Embedded promotional media for a product, such as images or videos. Each element contains exactly one media type.

Defined Under Namespace

Classes: EmbeddedImage, EmbeddedVideo, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#embedded_imageTypes::PromotionalEmbeddedImage

An embedded promotional image for a product.



2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2195

class PromotionalMedia < Struct.new(
  :embedded_image,
  :embedded_video,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EmbeddedImage < PromotionalMedia; end
  class EmbeddedVideo < PromotionalMedia; end
  class Unknown < PromotionalMedia; end
end

#embedded_videoTypes::PromotionalEmbeddedVideo

An embedded promotional video for a product.



2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2195

class PromotionalMedia < Struct.new(
  :embedded_image,
  :embedded_video,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EmbeddedImage < PromotionalMedia; end
  class EmbeddedVideo < PromotionalMedia; end
  class Unknown < PromotionalMedia; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2195
2196
2197
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2195

def unknown
  @unknown
end