Class: Aws::MarketplaceDiscovery::Types::PurchaseOptionAssociatedEntity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A product, offer, and optional offer set associated with a purchase option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#offerTypes::OfferInformation

Information about the offer associated with the purchase option.



2226
2227
2228
2229
2230
2231
2232
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2226

class PurchaseOptionAssociatedEntity < Struct.new(
  :product,
  :offer,
  :offer_set)
  SENSITIVE = []
  include Aws::Structure
end

#offer_setTypes::OfferSetInformation

Information about the offer set, if the purchase option is part of a bundled offer set.



2226
2227
2228
2229
2230
2231
2232
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2226

class PurchaseOptionAssociatedEntity < Struct.new(
  :product,
  :offer,
  :offer_set)
  SENSITIVE = []
  include Aws::Structure
end

#productTypes::ProductInformation

Information about the product associated with the purchase option.



2226
2227
2228
2229
2230
2231
2232
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2226

class PurchaseOptionAssociatedEntity < Struct.new(
  :product,
  :offer,
  :offer_set)
  SENSITIVE = []
  include Aws::Structure
end