Class: Aws::MarketplaceDiscovery::Types::RateCardItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A per-unit rate within a rate card, defining the price for a specific dimension.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the dimension being priced.

Returns:

  • (String)


2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367

class RateCardItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#dimension_keyString

The machine-readable key identifying the dimension being priced.

Returns:

  • (String)


2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367

class RateCardItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#dimension_labelsArray<Types::DimensionLabel>

Labels used to categorize this dimension, such as by region.

Returns:



2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367

class RateCardItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

The human-readable name of the dimension.

Returns:

  • (String)


2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367

class RateCardItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#priceString

The price per unit for the dimension.

Returns:

  • (String)


2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367

class RateCardItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#unitString

The unit of measurement for the dimension.

Returns:

  • (String)


2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367

class RateCardItem < Struct.new(
  :dimension_key,
  :display_name,
  :description,
  :dimension_labels,
  :unit,
  :price)
  SENSITIVE = []
  include Aws::Structure
end