Class: Aws::MarketplaceDiscovery::Types::RecurringPaymentTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a recurring payment term with fixed charges at regular billing intervals.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#billing_periodString

The billing period frequency, such as Monthly.

Returns:

  • (String)


2403
2404
2405
2406
2407
2408
2409
2410
2411
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403

class RecurringPaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :billing_period,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#currency_codeString

Defines the currency for the prices in this term.

Returns:

  • (String)


2403
2404
2405
2406
2407
2408
2409
2410
2411
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403

class RecurringPaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :billing_period,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the term.

Returns:

  • (String)


2403
2404
2405
2406
2407
2408
2409
2410
2411
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403

class RecurringPaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :billing_period,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#priceString

The amount charged each billing period.

Returns:

  • (String)


2403
2404
2405
2406
2407
2408
2409
2410
2411
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403

class RecurringPaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :billing_period,
  :price)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:

  • (String)


2403
2404
2405
2406
2407
2408
2409
2410
2411
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403

class RecurringPaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :billing_period,
  :price)
  SENSITIVE = []
  include Aws::Structure
end