Class: Aws::MarketplaceDiscovery::Types::RenewalTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a renewal term that enables automatic agreement renewal.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#adjustment_deadlineString

The duration before the agreement end date by which the renewal price is finalized, represented in ISO 8601 format (for example, P30D). Only applicable with PercentageRange.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452

class RenewalTerm < Struct.new(
  :id,
  :type,
  :max_renewals,
  :lockout_period,
  :adjustment_deadline,
  :price_increase,
  :term_templates)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the term.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452

class RenewalTerm < Struct.new(
  :id,
  :type,
  :max_renewals,
  :lockout_period,
  :adjustment_deadline,
  :price_increase,
  :term_templates)
  SENSITIVE = []
  include Aws::Structure
end

#lockout_periodString

The duration before the agreement end date when the lockout window begins, in ISO 8601 format (for example, P30D). Absent means no lockout.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452

class RenewalTerm < Struct.new(
  :id,
  :type,
  :max_renewals,
  :lockout_period,
  :adjustment_deadline,
  :price_increase,
  :term_templates)
  SENSITIVE = []
  include Aws::Structure
end

#max_renewalsInteger

The maximum number of renewals allowed on this offer. Absent means unlimited renewals.

Returns:

  • (Integer)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452

class RenewalTerm < Struct.new(
  :id,
  :type,
  :max_renewals,
  :lockout_period,
  :adjustment_deadline,
  :price_increase,
  :term_templates)
  SENSITIVE = []
  include Aws::Structure
end

#price_increaseTypes::PriceIncrease

The price increase applied at each renewal cycle. Absent means identical pricing on renewal.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452

class RenewalTerm < Struct.new(
  :id,
  :type,
  :max_renewals,
  :lockout_period,
  :adjustment_deadline,
  :price_increase,
  :term_templates)
  SENSITIVE = []
  include Aws::Structure
end

#term_templatesArray<Types::TermTemplate>

Structural templates defining how specific terms are reshaped on each renewal cycle. Absent for upfront-only offers.

Returns:



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452

class RenewalTerm < Struct.new(
  :id,
  :type,
  :max_renewals,
  :lockout_period,
  :adjustment_deadline,
  :price_increase,
  :term_templates)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:

  • (String)


2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452

class RenewalTerm < Struct.new(
  :id,
  :type,
  :max_renewals,
  :lockout_period,
  :adjustment_deadline,
  :price_increase,
  :term_templates)
  SENSITIVE = []
  include Aws::Structure
end