Class: Aws::MarketplaceDiscovery::Types::Resource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A resource that provides supplementary information about a product, such as documentation links, support contacts, or usage instructions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_typeString

The format of the resource content, such as a URL, email address, or text.

Returns:

  • (String)


2487
2488
2489
2490
2491
2492
2493
2494
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2487

class Resource < Struct.new(
  :resource_type,
  :content_type,
  :value,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#display_nameString

An optional human-readable label for the resource.

Returns:

  • (String)


2487
2488
2489
2490
2491
2492
2493
2494
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2487

class Resource < Struct.new(
  :resource_type,
  :content_type,
  :value,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The category of the resource, such as manufacturer support or usage instructions.

Returns:

  • (String)


2487
2488
2489
2490
2491
2492
2493
2494
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2487

class Resource < Struct.new(
  :resource_type,
  :content_type,
  :value,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The resource content. Interpretation depends on the content type.

Returns:

  • (String)


2487
2488
2489
2490
2491
2492
2493
2494
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2487

class Resource < Struct.new(
  :resource_type,
  :content_type,
  :value,
  :display_name)
  SENSITIVE = []
  include Aws::Structure
end