Class: Aws::MarketplaceDiscovery::Types::ReviewSourceSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

A review summary from a specific source, including the average rating and total review count.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#average_ratingString

The average rating across all reviews from this source.



2534
2535
2536
2537
2538
2539
2540
2541
2542
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534

class ReviewSourceSummary < Struct.new(
  :source_name,
  :source_id,
  :source_url,
  :average_rating,
  :total_reviews)
  SENSITIVE = []
  include Aws::Structure
end

#source_idString

The machine-readable identifier of the review source.



2534
2535
2536
2537
2538
2539
2540
2541
2542
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534

class ReviewSourceSummary < Struct.new(
  :source_name,
  :source_id,
  :source_url,
  :average_rating,
  :total_reviews)
  SENSITIVE = []
  include Aws::Structure
end

#source_nameString

The name of the review source, such as AWS Marketplace.



2534
2535
2536
2537
2538
2539
2540
2541
2542
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534

class ReviewSourceSummary < Struct.new(
  :source_name,
  :source_id,
  :source_url,
  :average_rating,
  :total_reviews)
  SENSITIVE = []
  include Aws::Structure
end

#source_urlString

The URL where the reviews can be accessed at the source.



2534
2535
2536
2537
2538
2539
2540
2541
2542
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534

class ReviewSourceSummary < Struct.new(
  :source_name,
  :source_id,
  :source_url,
  :average_rating,
  :total_reviews)
  SENSITIVE = []
  include Aws::Structure
end

#total_reviewsInteger

The total number of reviews available from this source.



2534
2535
2536
2537
2538
2539
2540
2541
2542
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534

class ReviewSourceSummary < Struct.new(
  :source_name,
  :source_id,
  :source_url,
  :average_rating,
  :total_reviews)
  SENSITIVE = []
  include Aws::Structure
end