Class: Aws::MarketplaceDiscovery::Types::SaasFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::SaasFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes a Software as a Service (SaaS) fulfillment option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
-
#fulfillment_url ⇒ String
The URL of the seller's software registration landing page.
-
#usage_instructions ⇒ String
Instructions on how to access and use this SaaS product.
Instance Attribute Details
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2583 class SaasFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_url, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2583 class SaasFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_url, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2583 class SaasFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_url, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_url ⇒ String
The URL of the seller's software registration landing page.
2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2583 class SaasFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_url, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#usage_instructions ⇒ String
Instructions on how to access and use this SaaS product.
2583 2584 2585 2586 2587 2588 2589 2590 2591 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2583 class SaasFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_url, :usage_instructions) SENSITIVE = [] include Aws::Structure end |