Class: Aws::MarketplaceDiscovery::Types::SageMakerModelFulfillmentOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Describes an Amazon SageMaker model fulfillment option, including version details and recommended instance types.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fulfillment_option_display_nameString

A human-readable name for the fulfillment option type.

Returns:

  • (String)


2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699

class SageMakerModelFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :release_notes,
  :usage_instructions,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_idString

The unique identifier of the fulfillment option.

Returns:

  • (String)


2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699

class SageMakerModelFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :release_notes,
  :usage_instructions,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_typeString

The category of the fulfillment option.

Returns:

  • (String)


2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699

class SageMakerModelFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :release_notes,
  :usage_instructions,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#fulfillment_option_versionString

The version identifier of the fulfillment option.

Returns:

  • (String)


2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699

class SageMakerModelFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :release_notes,
  :usage_instructions,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationTypes::SageMakerModelRecommendation

Recommended instance types for inference with this model.



2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699

class SageMakerModelFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :release_notes,
  :usage_instructions,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#release_notesString

Release notes describing changes in this version of the fulfillment option.

Returns:

  • (String)


2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699

class SageMakerModelFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :release_notes,
  :usage_instructions,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end

#usage_instructionsString

Instructions on how to use this SageMaker model.

Returns:

  • (String)


2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699

class SageMakerModelFulfillmentOption < Struct.new(
  :fulfillment_option_id,
  :fulfillment_option_type,
  :fulfillment_option_display_name,
  :fulfillment_option_version,
  :release_notes,
  :usage_instructions,
  :recommendation)
  SENSITIVE = []
  include Aws::Structure
end