Class: Aws::MarketplaceDiscovery::Types::ScheduleItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::ScheduleItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A payment installment within a payment schedule term.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#charge_amount ⇒ String
The amount to be charged on the charge date.
-
#charge_date ⇒ Time
The date when the payment is due.
Instance Attribute Details
#charge_amount ⇒ String
The amount to be charged on the charge date.
2742 2743 2744 2745 2746 2747 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2742 class ScheduleItem < Struct.new( :charge_date, :charge_amount) SENSITIVE = [] include Aws::Structure end |
#charge_date ⇒ Time
The date when the payment is due.
2742 2743 2744 2745 2746 2747 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2742 class ScheduleItem < Struct.new( :charge_date, :charge_amount) SENSITIVE = [] include Aws::Structure end |