Class: Aws::MarketplaceDiscovery::Types::SearchFacetsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#listing_facetsHash<String,Array<Types::ListingFacet>>

A map of facet types to their corresponding facet values. Each facet value includes a display name, internal value, and count of matching listings.

Returns:



2797
2798
2799
2800
2801
2802
2803
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2797

class SearchFacetsOutput < Struct.new(
  :total_results,
  :listing_facets,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page.

Returns:



2797
2798
2799
2800
2801
2802
2803
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2797

class SearchFacetsOutput < Struct.new(
  :total_results,
  :listing_facets,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#total_resultsInteger

The total number of listings matching the search criteria.

Returns:



2797
2798
2799
2800
2801
2802
2803
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2797

class SearchFacetsOutput < Struct.new(
  :total_results,
  :listing_facets,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end