Class: Aws::MarketplaceDiscovery::Types::SellerEngagement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

An engagement option available to potential buyers of a product, such as requesting a private offer or a demo.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_typeString

The format of the engagement value, such as a URL.

Returns:

  • (String)


2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2932

class SellerEngagement < Struct.new(
  :engagement_type,
  :content_type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#engagement_typeString

The type of engagement, such as REQUEST_FOR_PRIVATE_OFFER or REQUEST_FOR_DEMO.

Returns:

  • (String)


2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2932

class SellerEngagement < Struct.new(
  :engagement_type,
  :content_type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The engagement value, such as a URL to the engagement form.

Returns:

  • (String)


2932
2933
2934
2935
2936
2937
2938
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2932

class SellerEngagement < Struct.new(
  :engagement_type,
  :content_type,
  :value)
  SENSITIVE = []
  include Aws::Structure
end