Class: Aws::MarketplaceDiscovery::Types::UsageBasedPricingTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::UsageBasedPricingTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a usage-based pricing term (typically pay-as-you-go), where buyers are charged based on product usage.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
Defines the currency for the prices in this term.
-
#id ⇒ String
The unique identifier of the term.
-
#rate_cards ⇒ Array<Types::UsageBasedRateCardItem>
The rate cards containing per-unit rates for usage-based pricing.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#currency_code ⇒ String
Defines the currency for the prices in this term.
3041 3042 3043 3044 3045 3046 3047 3048 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3041 class UsageBasedPricingTerm < Struct.new( :id, :type, :currency_code, :rate_cards) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
3041 3042 3043 3044 3045 3046 3047 3048 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3041 class UsageBasedPricingTerm < Struct.new( :id, :type, :currency_code, :rate_cards) SENSITIVE = [] include Aws::Structure end |
#rate_cards ⇒ Array<Types::UsageBasedRateCardItem>
The rate cards containing per-unit rates for usage-based pricing.
3041 3042 3043 3044 3045 3046 3047 3048 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3041 class UsageBasedPricingTerm < Struct.new( :id, :type, :currency_code, :rate_cards) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
3041 3042 3043 3044 3045 3046 3047 3048 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3041 class UsageBasedPricingTerm < Struct.new( :id, :type, :currency_code, :rate_cards) SENSITIVE = [] include Aws::Structure end |