Class: Aws::MarketplaceDiscovery::Types::ValidationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

The input fails to satisfy the constraints specified by the service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3115
3116
3117
3118
3119
3120
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3115

class ValidationException < Struct.new(
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason that the input fails to satisfy the constraints specified by the service.

Returns:

  • (String)


3115
3116
3117
3118
3119
3120
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3115

class ValidationException < Struct.new(
  :message,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end