Class: Aws::MarketplaceDiscovery::Types::VariablePaymentTerm

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacediscovery/types.rb

Overview

Defines a variable payment term with a maximum total charge amount.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currency_codeString

Defines the currency for the prices in this term.

Returns:

  • (String)


3177
3178
3179
3180
3181
3182
3183
3184
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3177

class VariablePaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :max_total_charge_amount)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the term.

Returns:

  • (String)


3177
3178
3179
3180
3181
3182
3183
3184
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3177

class VariablePaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :max_total_charge_amount)
  SENSITIVE = []
  include Aws::Structure
end

#max_total_charge_amountString

The maximum total amount that can be charged under this term.

Returns:

  • (String)


3177
3178
3179
3180
3181
3182
3183
3184
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3177

class VariablePaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :max_total_charge_amount)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The category of the term.

Returns:

  • (String)


3177
3178
3179
3180
3181
3182
3183
3184
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3177

class VariablePaymentTerm < Struct.new(
  :id,
  :type,
  :currency_code,
  :max_total_charge_amount)
  SENSITIVE = []
  include Aws::Structure
end