Class: Aws::MarketplaceDiscovery::Types::AmazonMachineImageFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::AmazonMachineImageFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes an Amazon Machine Image (AMI) fulfillment option, including version details, supported operating systems, and recommended instance types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
-
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
-
#operating_systems ⇒ Array<Types::AmazonMachineImageOperatingSystem>
The operating systems supported by this AMI.
-
#recommendation ⇒ Types::AmazonMachineImageRecommendation
Recommended instance types for running this AMI.
-
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
-
#usage_instructions ⇒ String
Instructions on how to deploy and use this fulfillment option.
Instance Attribute Details
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#operating_systems ⇒ Array<Types::AmazonMachineImageOperatingSystem>
The operating systems supported by this AMI.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#recommendation ⇒ Types::AmazonMachineImageRecommendation
Recommended instance types for running this AMI.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#usage_instructions ⇒ String
Instructions on how to deploy and use this fulfillment option.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 69 class AmazonMachineImageFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_version, :fulfillment_option_type, :fulfillment_option_display_name, :operating_systems, :recommendation, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |