Class: Aws::MarketplaceDiscovery::Types::AmazonMachineImageOperatingSystem
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::AmazonMachineImageOperatingSystem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes an operating system supported by an AMI fulfillment option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operating_system_family_name ⇒ String
The operating system family, such as Linux or Windows.
-
#operating_system_name ⇒ String
The specific operating system name, such as Amazon Linux 2 or Windows Server 2022.
-
#operating_system_version ⇒ String
The version of the operating system.
Instance Attribute Details
#operating_system_family_name ⇒ String
The operating system family, such as Linux or Windows.
100 101 102 103 104 105 106 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 100 class AmazonMachineImageOperatingSystem < Struct.new( :operating_system_family_name, :operating_system_name, :operating_system_version) SENSITIVE = [] include Aws::Structure end |
#operating_system_name ⇒ String
The specific operating system name, such as Amazon Linux 2 or Windows Server 2022.
100 101 102 103 104 105 106 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 100 class AmazonMachineImageOperatingSystem < Struct.new( :operating_system_family_name, :operating_system_name, :operating_system_version) SENSITIVE = [] include Aws::Structure end |
#operating_system_version ⇒ String
The version of the operating system.
100 101 102 103 104 105 106 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 100 class AmazonMachineImageOperatingSystem < Struct.new( :operating_system_family_name, :operating_system_name, :operating_system_version) SENSITIVE = [] include Aws::Structure end |