Class: Aws::MarketplaceDiscovery::Types::ApiFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::ApiFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes an API-based fulfillment option, where the product is accessed through an API integration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this API integration.
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
-
#usage_instructions ⇒ String
Instructions on how to integrate with and use this API.
Instance Attribute Details
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this API integration.
147 148 149 150 151 152 153 154 155 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147 class ApiFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
147 148 149 150 151 152 153 154 155 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147 class ApiFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
147 148 149 150 151 152 153 154 155 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147 class ApiFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
147 148 149 150 151 152 153 154 155 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147 class ApiFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |
#usage_instructions ⇒ String
Instructions on how to integrate with and use this API.
147 148 149 150 151 152 153 154 155 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 147 class ApiFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :usage_instructions, :aws_supported_services) SENSITIVE = [] include Aws::Structure end |