Class: Aws::MarketplaceDiscovery::Types::ConfigurableUpfrontPricingTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::ConfigurableUpfrontPricingTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a configurable upfront pricing term with selectable rate cards, where buyers choose from predefined pricing configurations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
Defines the currency for the prices in this term.
-
#id ⇒ String
The unique identifier of the term.
-
#rate_cards ⇒ Array<Types::ConfigurableUpfrontRateCardItem>
The rate cards available for selection, each with a selector, constraints, and per-unit rates.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#currency_code ⇒ String
Defines the currency for the prices in this term.
288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 288 class ConfigurableUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :rate_cards) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 288 class ConfigurableUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :rate_cards) SENSITIVE = [] include Aws::Structure end |
#rate_cards ⇒ Array<Types::ConfigurableUpfrontRateCardItem>
The rate cards available for selection, each with a selector, constraints, and per-unit rates.
288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 288 class ConfigurableUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :rate_cards) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
288 289 290 291 292 293 294 295 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 288 class ConfigurableUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :rate_cards) SENSITIVE = [] include Aws::Structure end |