Class: Aws::MarketplaceDiscovery::Types::DataArtifact
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::DataArtifact
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes a data artifact within a Data Exchange fulfillment option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_classification ⇒ String
The classification of sensitive data contained in the dataset.
-
#description ⇒ String
A description of the data artifact.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the data artifact.
-
#resource_type ⇒ String
The type of the data artifact resource.
Instance Attribute Details
#data_classification ⇒ String
The classification of sensitive data contained in the dataset.
440 441 442 443 444 445 446 447 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 440 class DataArtifact < Struct.new( :description, :resource_arn, :resource_type, :data_classification) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the data artifact.
440 441 442 443 444 445 446 447 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 440 class DataArtifact < Struct.new( :description, :resource_arn, :resource_type, :data_classification) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the data artifact.
440 441 442 443 444 445 446 447 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 440 class DataArtifact < Struct.new( :description, :resource_arn, :resource_type, :data_classification) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of the data artifact resource.
440 441 442 443 444 445 446 447 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 440 class DataArtifact < Struct.new( :description, :resource_arn, :resource_type, :data_classification) SENSITIVE = [] include Aws::Structure end |