Class: Aws::MarketplaceDiscovery::Types::DimensionLabel
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::DimensionLabel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A label used to group or categorize pricing dimensions, such as by region or SageMaker option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The human-readable display name of the label.
-
#label_type ⇒ String
The type of the dimension label, such as
RegionorSagemakerOption. -
#label_value ⇒ String
The value used to group dimensions together.
Instance Attribute Details
#display_name ⇒ String
The human-readable display name of the label.
498 499 500 501 502 503 504 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 498 class DimensionLabel < Struct.new( :label_type, :label_value, :display_name) SENSITIVE = [] include Aws::Structure end |
#label_type ⇒ String
The type of the dimension label, such as Region or
SagemakerOption.
498 499 500 501 502 503 504 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 498 class DimensionLabel < Struct.new( :label_type, :label_value, :display_name) SENSITIVE = [] include Aws::Structure end |
#label_value ⇒ String
The value used to group dimensions together.
498 499 500 501 502 503 504 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 498 class DimensionLabel < Struct.new( :label_type, :label_value, :display_name) SENSITIVE = [] include Aws::Structure end |