Class: Aws::MarketplaceDiscovery::Types::DocumentItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::DocumentItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A legal document associated with a legal term, such as a EULA or data subscription agreement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
The category of the legal document, such as
StandardEulaorCustomEula. -
#url ⇒ String
The URL where the legal document can be accessed.
-
#version ⇒ String
The version of the standard contract, if applicable.
Instance Attribute Details
#type ⇒ String
The category of the legal document, such as StandardEula or
CustomEula.
524 525 526 527 528 529 530 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 524 class DocumentItem < Struct.new( :type, :url, :version) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
The URL where the legal document can be accessed.
524 525 526 527 528 529 530 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 524 class DocumentItem < Struct.new( :type, :url, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the standard contract, if applicable.
524 525 526 527 528 529 530 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 524 class DocumentItem < Struct.new( :type, :url, :version) SENSITIVE = [] include Aws::Structure end |