Class: Aws::MarketplaceDiscovery::Types::Ec2ImageBuilderComponentFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::Ec2ImageBuilderComponentFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes an EC2 Image Builder component fulfillment option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this EC2 Image Builder component.
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
-
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
-
#operating_systems ⇒ Array<Types::ContainerOperatingSystem>
The operating systems supported by this EC2 Image Builder component.
-
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
-
#usage_instructions ⇒ String
Instructions on how to deploy and use this EC2 Image Builder component.
Instance Attribute Details
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this EC2 Image Builder component.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#operating_systems ⇒ Array<Types::ContainerOperatingSystem>
The operating systems supported by this EC2 Image Builder component.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#usage_instructions ⇒ String
Instructions on how to deploy and use this EC2 Image Builder component.
574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 574 class Ec2ImageBuilderComponentFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :aws_supported_services, :release_notes, :usage_instructions) SENSITIVE = [] include Aws::Structure end |