Class: Aws::MarketplaceDiscovery::Types::FixedUpfrontPricingTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::FixedUpfrontPricingTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a fixed upfront pricing term with a pre-paid amount and granted entitlements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
Defines the currency for the prices in this term.
-
#duration ⇒ String
The duration of the fixed pricing term, in ISO 8601 format.
-
#grants ⇒ Array<Types::GrantItem>
The entitlements granted to the buyer as part of this term.
-
#id ⇒ String
The unique identifier of the term.
-
#price ⇒ String
The price charged upfront for this term.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#currency_code ⇒ String
Defines the currency for the prices in this term.
707 708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707 class FixedUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :duration, :price, :grants) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ String
The duration of the fixed pricing term, in ISO 8601 format.
707 708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707 class FixedUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :duration, :price, :grants) SENSITIVE = [] include Aws::Structure end |
#grants ⇒ Array<Types::GrantItem>
The entitlements granted to the buyer as part of this term.
707 708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707 class FixedUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :duration, :price, :grants) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
707 708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707 class FixedUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :duration, :price, :grants) SENSITIVE = [] include Aws::Structure end |
#price ⇒ String
The price charged upfront for this term.
707 708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707 class FixedUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :duration, :price, :grants) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
707 708 709 710 711 712 713 714 715 716 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 707 class FixedUpfrontPricingTerm < Struct.new( :id, :type, :currency_code, :duration, :price, :grants) SENSITIVE = [] include Aws::Structure end |