Class: Aws::MarketplaceDiscovery::Types::FreeTrialPricingTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::FreeTrialPricingTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a free trial pricing term that enables customers to try the product before purchasing.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration ⇒ String
The duration of the free trial period.
-
#grants ⇒ Array<Types::GrantItem>
The entitlements granted to the buyer during the free trial.
-
#id ⇒ String
The unique identifier of the term.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#duration ⇒ String
The duration of the free trial period.
739 740 741 742 743 744 745 746 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 739 class FreeTrialPricingTerm < Struct.new( :id, :type, :duration, :grants) SENSITIVE = [] include Aws::Structure end |
#grants ⇒ Array<Types::GrantItem>
The entitlements granted to the buyer during the free trial.
739 740 741 742 743 744 745 746 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 739 class FreeTrialPricingTerm < Struct.new( :id, :type, :duration, :grants) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
739 740 741 742 743 744 745 746 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 739 class FreeTrialPricingTerm < Struct.new( :id, :type, :duration, :grants) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
739 740 741 742 743 744 745 746 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 739 class FreeTrialPricingTerm < Struct.new( :id, :type, :duration, :grants) SENSITIVE = [] include Aws::Structure end |