Class: Aws::MarketplaceDiscovery::Types::FulfillmentOptionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::FulfillmentOptionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A summary of a fulfillment option available for deploying or accessing a listing or product.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The human-readable name of the fulfillment option type.
-
#fulfillment_option_type ⇒ String
The machine-readable type of the fulfillment option, such as
SAASorAMAZON_MACHINE_IMAGE.
Instance Attribute Details
#display_name ⇒ String
The human-readable name of the fulfillment option type.
851 852 853 854 855 856 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 851 class FulfillmentOptionSummary < Struct.new( :fulfillment_option_type, :display_name) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The machine-readable type of the fulfillment option, such as SAAS
or AMAZON_MACHINE_IMAGE.
851 852 853 854 855 856 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 851 class FulfillmentOptionSummary < Struct.new( :fulfillment_option_type, :display_name) SENSITIVE = [] include Aws::Structure end |