Class: Aws::MarketplaceDiscovery::Types::GetOfferOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::GetOfferOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agreement_proposal_id ⇒ String
An encoded string to be passed by the acceptor of the terms when creating an agreement.
-
#associated_entities ⇒ Array<Types::OfferAssociatedEntity>
The products and offer sets associated with this offer.
-
#available_from_time ⇒ Time
The date and time when the offer became available to the buyer.
-
#badges ⇒ Array<Types::PurchaseOptionBadge>
Badges indicating special attributes of the offer, such as private pricing, future dated, or replacement offer.
-
#catalog ⇒ String
The name of the catalog that the offer belongs to.
-
#expiration_time ⇒ Time
The date and time until when the offer can be procured.
-
#offer_id ⇒ String
The unique identifier of the offer.
-
#offer_name ⇒ String
The display name of the offer.
-
#pricing_model ⇒ Types::PricingModel
The pricing model that determines how buyers are charged, such as usage-based, contract, BYOL, or free.
-
#replacement_agreement_id ⇒ String
The identifier of the existing agreement that this offer would replace.
-
#seller_of_record ⇒ Types::SellerInformation
The entity responsible for selling the product under this offer.
Instance Attribute Details
#agreement_proposal_id ⇒ String
An encoded string to be passed by the acceptor of the terms when creating an agreement.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#associated_entities ⇒ Array<Types::OfferAssociatedEntity>
The products and offer sets associated with this offer.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#available_from_time ⇒ Time
The date and time when the offer became available to the buyer.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#badges ⇒ Array<Types::PurchaseOptionBadge>
Badges indicating special attributes of the offer, such as private pricing, future dated, or replacement offer.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#catalog ⇒ String
The name of the catalog that the offer belongs to.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#expiration_time ⇒ Time
The date and time until when the offer can be procured. This value is null for offers that never expire.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#offer_id ⇒ String
The unique identifier of the offer.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#offer_name ⇒ String
The display name of the offer. This is free-form text provided by the seller.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#pricing_model ⇒ Types::PricingModel
The pricing model that determines how buyers are charged, such as usage-based, contract, BYOL, or free.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#replacement_agreement_id ⇒ String
The identifier of the existing agreement that this offer would replace. Enables agreement-based offer functionality.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |
#seller_of_record ⇒ Types::SellerInformation
The entity responsible for selling the product under this offer.
1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1054 class GetOfferOutput < Struct.new( :offer_id, :catalog, :offer_name, :expiration_time, :available_from_time, :seller_of_record, :associated_entities, :agreement_proposal_id, :replacement_agreement_id, :pricing_model, :badges) SENSITIVE = [] include Aws::Structure end |