Class: Aws::MarketplaceDiscovery::Types::GetOfferTermsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::GetOfferTermsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that are returned per call.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#offer_id ⇒ String
The unique identifier of the offer whose terms to retrieve.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that are returned per call. You can
use nextToken to get more results.
1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1154 class GetOfferTermsInput < Struct.new( :offer_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. Make
the call again using the returned token to retrieve the next page.
1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1154 class GetOfferTermsInput < Struct.new( :offer_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#offer_id ⇒ String
The unique identifier of the offer whose terms to retrieve.
1154 1155 1156 1157 1158 1159 1160 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1154 class GetOfferTermsInput < Struct.new( :offer_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |