Class: Aws::MarketplaceDiscovery::Types::GrantItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::GrantItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
An entitlement granted to the buyer as part of a pricing term.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the entitlement.
-
#dimension_key ⇒ String
The machine-readable key identifying the entitlement dimension.
-
#dimension_labels ⇒ Array<Types::DimensionLabel>
Labels used to categorize this entitlement, such as by region.
-
#display_name ⇒ String
The human-readable name of the entitlement dimension.
-
#max_quantity ⇒ Integer
The maximum quantity of the entitlement that can be granted.
-
#unit ⇒ String
The unit of measurement for the entitlement.
Instance Attribute Details
#description ⇒ String
A description of the entitlement.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304 class GrantItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :max_quantity) SENSITIVE = [] include Aws::Structure end |
#dimension_key ⇒ String
The machine-readable key identifying the entitlement dimension.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304 class GrantItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :max_quantity) SENSITIVE = [] include Aws::Structure end |
#dimension_labels ⇒ Array<Types::DimensionLabel>
Labels used to categorize this entitlement, such as by region.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304 class GrantItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :max_quantity) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The human-readable name of the entitlement dimension.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304 class GrantItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :max_quantity) SENSITIVE = [] include Aws::Structure end |
#max_quantity ⇒ Integer
The maximum quantity of the entitlement that can be granted.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304 class GrantItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :max_quantity) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The unit of measurement for the entitlement.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1304 class GrantItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :max_quantity) SENSITIVE = [] include Aws::Structure end |