Class: Aws::MarketplaceDiscovery::Types::HelmFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::HelmFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes a Helm chart fulfillment option for Kubernetes deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this Helm chart deployment.
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
-
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
-
#operating_systems ⇒ Array<Types::HelmOperatingSystem>
The operating systems supported by this Helm chart.
-
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
-
#usage_instructions ⇒ String
Instructions on how to deploy and use this Helm chart.
Instance Attribute Details
#aws_supported_services ⇒ Array<Types::AwsSupportedService>
The AWS services supported by this Helm chart deployment.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_name ⇒ String
The display name of the fulfillment option version.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#operating_systems ⇒ Array<Types::HelmOperatingSystem>
The operating systems supported by this Helm chart.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |
#usage_instructions ⇒ String
Instructions on how to deploy and use this Helm chart.
1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1356 class HelmFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_name, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :operating_systems, :release_notes, :aws_supported_services, :usage_instructions) SENSITIVE = [] include Aws::Structure end |