Class: Aws::MarketplaceDiscovery::Types::LegalTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::LegalTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a legal term containing documents proposed to buyers, such as EULAs and data subscription agreements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#documents ⇒ Array<Types::DocumentItem>
The legal documents proposed to the buyer as part of this term.
-
#id ⇒ String
The unique identifier of the term.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#documents ⇒ Array<Types::DocumentItem>
The legal documents proposed to the buyer as part of this term.
1420 1421 1422 1423 1424 1425 1426 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1420 class LegalTerm < Struct.new( :id, :type, :documents) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
1420 1421 1422 1423 1424 1425 1426 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1420 class LegalTerm < Struct.new( :id, :type, :documents) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
1420 1421 1422 1423 1424 1425 1426 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1420 class LegalTerm < Struct.new( :id, :type, :documents) SENSITIVE = [] include Aws::Structure end |