Class: Aws::MarketplaceDiscovery::Types::OfferSetAssociatedEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::OfferSetAssociatedEntity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A product and offer associated with an offer set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#offer ⇒ Types::OfferInformation
Information about the offer associated with the offer set.
-
#product ⇒ Types::ProductInformation
Information about the product associated with the offer set.
Instance Attribute Details
#offer ⇒ Types::OfferInformation
Information about the offer associated with the offer set.
1763 1764 1765 1766 1767 1768 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1763 class OfferSetAssociatedEntity < Struct.new( :product, :offer) SENSITIVE = [] include Aws::Structure end |
#product ⇒ Types::ProductInformation
Information about the product associated with the offer set.
1763 1764 1765 1766 1767 1768 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1763 class OfferSetAssociatedEntity < Struct.new( :product, :offer) SENSITIVE = [] include Aws::Structure end |