Class: Aws::MarketplaceDiscovery::Types::PaymentScheduleEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::PaymentScheduleEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A single installment entry in the renewal payment schedule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#charge_date_offset ⇒ String
The relative offset from the renewal agreement start date when this installment is due, in ISO 8601 duration format.
-
#charge_percentage ⇒ String
The percentage of the increased TCV to charge in this installment.
-
#day_of_month ⇒ Integer
The optional calendar day of month on which the charge occurs.
Instance Attribute Details
#charge_date_offset ⇒ String
The relative offset from the renewal agreement start date when this installment is due, in ISO 8601 duration format. The offset uses months only or days only (for example, P1M or P30D); mixed units are not supported, and every offset in a schedule uses the same unit.
1920 1921 1922 1923 1924 1925 1926 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1920 class PaymentScheduleEntry < Struct.new( :charge_date_offset, :charge_percentage, :day_of_month) SENSITIVE = [] include Aws::Structure end |
#charge_percentage ⇒ String
The percentage of the increased TCV to charge in this installment. All entries in a schedule sum to 100.00.
1920 1921 1922 1923 1924 1925 1926 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1920 class PaymentScheduleEntry < Struct.new( :charge_date_offset, :charge_percentage, :day_of_month) SENSITIVE = [] include Aws::Structure end |
#day_of_month ⇒ Integer
The optional calendar day of month on which the charge occurs. When
absent, the charge day is derived from chargeDateOffset, and this
field does not apply when chargeDateOffset is expressed in days.
For months with fewer days than the specified day, the charge occurs
on the last day of the month. For example, if dayOfMonth is 31,
the charge in April occurs on April 30.
1920 1921 1922 1923 1924 1925 1926 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1920 class PaymentScheduleEntry < Struct.new( :charge_date_offset, :charge_percentage, :day_of_month) SENSITIVE = [] include Aws::Structure end |