Class: Aws::MarketplaceDiscovery::Types::PaymentScheduleTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::PaymentScheduleTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a payment schedule term with installment payments at specified dates.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
Defines the currency for the prices in this term.
-
#id ⇒ String
The unique identifier of the term.
-
#schedule ⇒ Array<Types::ScheduleItem>
The payment schedule installments, each with a charge date and amount.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#currency_code ⇒ String
Defines the currency for the prices in this term.
1950 1951 1952 1953 1954 1955 1956 1957 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1950 class PaymentScheduleTerm < Struct.new( :id, :type, :currency_code, :schedule) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
1950 1951 1952 1953 1954 1955 1956 1957 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1950 class PaymentScheduleTerm < Struct.new( :id, :type, :currency_code, :schedule) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Array<Types::ScheduleItem>
The payment schedule installments, each with a charge date and amount.
1950 1951 1952 1953 1954 1955 1956 1957 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1950 class PaymentScheduleTerm < Struct.new( :id, :type, :currency_code, :schedule) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
1950 1951 1952 1953 1954 1955 1956 1957 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 1950 class PaymentScheduleTerm < Struct.new( :id, :type, :currency_code, :schedule) SENSITIVE = [] include Aws::Structure end |