Class: Aws::MarketplaceDiscovery::Types::PricingUnit
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::PricingUnit
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A pricing unit that defines the billing dimension for a listing, such as users, hosts, bandwidth, or data.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#display_name ⇒ String
The human-readable name of the pricing unit.
-
#pricing_unit_type ⇒ String
The machine-readable type of the pricing unit.
Instance Attribute Details
#display_name ⇒ String
The human-readable name of the pricing unit.
2066 2067 2068 2069 2070 2071 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2066 class PricingUnit < Struct.new( :pricing_unit_type, :display_name) SENSITIVE = [] include Aws::Structure end |
#pricing_unit_type ⇒ String
The machine-readable type of the pricing unit.
2066 2067 2068 2069 2070 2071 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2066 class PricingUnit < Struct.new( :pricing_unit_type, :display_name) SENSITIVE = [] include Aws::Structure end |