Class: Aws::MarketplaceDiscovery::Types::PurchaseOptionAssociatedEntity
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::PurchaseOptionAssociatedEntity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A product, offer, and optional offer set associated with a purchase option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#offer ⇒ Types::OfferInformation
Information about the offer associated with the purchase option.
-
#offer_set ⇒ Types::OfferSetInformation
Information about the offer set, if the purchase option is part of a bundled offer set.
-
#product ⇒ Types::ProductInformation
Information about the product associated with the purchase option.
Instance Attribute Details
#offer ⇒ Types::OfferInformation
Information about the offer associated with the purchase option.
2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2226 class PurchaseOptionAssociatedEntity < Struct.new( :product, :offer, :offer_set) SENSITIVE = [] include Aws::Structure end |
#offer_set ⇒ Types::OfferSetInformation
Information about the offer set, if the purchase option is part of a bundled offer set.
2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2226 class PurchaseOptionAssociatedEntity < Struct.new( :product, :offer, :offer_set) SENSITIVE = [] include Aws::Structure end |
#product ⇒ Types::ProductInformation
Information about the product associated with the purchase option.
2226 2227 2228 2229 2230 2231 2232 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2226 class PurchaseOptionAssociatedEntity < Struct.new( :product, :offer, :offer_set) SENSITIVE = [] include Aws::Structure end |