Class: Aws::MarketplaceDiscovery::Types::PurchaseOptionBadge
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::PurchaseOptionBadge
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A badge indicating a special attribute of a purchase option, such as private pricing or future dated.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#badge_type ⇒ String
The machine-readable type of the badge.
-
#display_name ⇒ String
The human-readable name of the badge.
Instance Attribute Details
#badge_type ⇒ String
The machine-readable type of the badge.
2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2247 class PurchaseOptionBadge < Struct.new( :display_name, :badge_type) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The human-readable name of the badge.
2247 2248 2249 2250 2251 2252 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2247 class PurchaseOptionBadge < Struct.new( :display_name, :badge_type) SENSITIVE = [] include Aws::Structure end |