Class: Aws::MarketplaceDiscovery::Types::PurchaseOptionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::PurchaseOptionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Summary information about a purchase option (offer or offer set) available to the buyer, including the seller, badges, and associated products.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#associated_entities ⇒ Array<Types::PurchaseOptionAssociatedEntity>
The products, offers, and offer sets associated with this purchase option.
-
#available_from_time ⇒ Time
The date and time when the purchase option became available to the buyer.
-
#badges ⇒ Array<Types::PurchaseOptionBadge>
Badges indicating special attributes of the purchase option, such as private pricing or future dated.
-
#catalog ⇒ String
The name of the catalog that the purchase option belongs to.
-
#expiration_time ⇒ Time
The date and time when the purchase option expires and is no longer available for procurement.
-
#purchase_option_id ⇒ String
The unique identifier of the purchase option.
-
#purchase_option_name ⇒ String
The display name of the purchase option.
-
#purchase_option_type ⇒ String
The type of purchase option.
-
#seller_of_record ⇒ Types::SellerInformation
The entity responsible for selling the product under this purchase option.
Instance Attribute Details
#associated_entities ⇒ Array<Types::PurchaseOptionAssociatedEntity>
The products, offers, and offer sets associated with this purchase option.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |
#available_from_time ⇒ Time
The date and time when the purchase option became available to the buyer.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |
#badges ⇒ Array<Types::PurchaseOptionBadge>
Badges indicating special attributes of the purchase option, such as private pricing or future dated.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |
#catalog ⇒ String
The name of the catalog that the purchase option belongs to.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |
#expiration_time ⇒ Time
The date and time when the purchase option expires and is no longer available for procurement.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |
#purchase_option_id ⇒ String
The unique identifier of the purchase option.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |
#purchase_option_name ⇒ String
The display name of the purchase option.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |
#purchase_option_type ⇒ String
The type of purchase option. Values are OFFER for a single-product
offer or OFFERSET for a bundled offer set.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |
#seller_of_record ⇒ Types::SellerInformation
The entity responsible for selling the product under this purchase option.
2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2324 class PurchaseOptionSummary < Struct.new( :purchase_option_id, :catalog, :purchase_option_type, :purchase_option_name, :available_from_time, :expiration_time, :seller_of_record, :badges, :associated_entities) SENSITIVE = [] include Aws::Structure end |