Class: Aws::MarketplaceDiscovery::Types::RateCardItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::RateCardItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A per-unit rate within a rate card, defining the price for a specific dimension.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the dimension being priced.
-
#dimension_key ⇒ String
The machine-readable key identifying the dimension being priced.
-
#dimension_labels ⇒ Array<Types::DimensionLabel>
Labels used to categorize this dimension, such as by region.
-
#display_name ⇒ String
The human-readable name of the dimension.
-
#price ⇒ String
The price per unit for the dimension.
-
#unit ⇒ String
The unit of measurement for the dimension.
Instance Attribute Details
#description ⇒ String
A description of the dimension being priced.
2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367 class RateCardItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :price) SENSITIVE = [] include Aws::Structure end |
#dimension_key ⇒ String
The machine-readable key identifying the dimension being priced.
2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367 class RateCardItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :price) SENSITIVE = [] include Aws::Structure end |
#dimension_labels ⇒ Array<Types::DimensionLabel>
Labels used to categorize this dimension, such as by region.
2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367 class RateCardItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :price) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
The human-readable name of the dimension.
2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367 class RateCardItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :price) SENSITIVE = [] include Aws::Structure end |
#price ⇒ String
The price per unit for the dimension.
2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367 class RateCardItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :price) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The unit of measurement for the dimension.
2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2367 class RateCardItem < Struct.new( :dimension_key, :display_name, :description, :dimension_labels, :unit, :price) SENSITIVE = [] include Aws::Structure end |