Class: Aws::MarketplaceDiscovery::Types::RecurringPaymentTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::RecurringPaymentTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a recurring payment term with fixed charges at regular billing intervals.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_period ⇒ String
The billing period frequency, such as
Monthly. -
#currency_code ⇒ String
Defines the currency for the prices in this term.
-
#id ⇒ String
The unique identifier of the term.
-
#price ⇒ String
The amount charged each billing period.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#billing_period ⇒ String
The billing period frequency, such as Monthly.
2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403 class RecurringPaymentTerm < Struct.new( :id, :type, :currency_code, :billing_period, :price) SENSITIVE = [] include Aws::Structure end |
#currency_code ⇒ String
Defines the currency for the prices in this term.
2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403 class RecurringPaymentTerm < Struct.new( :id, :type, :currency_code, :billing_period, :price) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403 class RecurringPaymentTerm < Struct.new( :id, :type, :currency_code, :billing_period, :price) SENSITIVE = [] include Aws::Structure end |
#price ⇒ String
The amount charged each billing period.
2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403 class RecurringPaymentTerm < Struct.new( :id, :type, :currency_code, :billing_period, :price) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2403 class RecurringPaymentTerm < Struct.new( :id, :type, :currency_code, :billing_period, :price) SENSITIVE = [] include Aws::Structure end |