Class: Aws::MarketplaceDiscovery::Types::RenewalTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::RenewalTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a renewal term that enables automatic agreement renewal.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#adjustment_deadline ⇒ String
The duration before the agreement end date by which the renewal price is finalized, represented in ISO 8601 format (for example, P30D).
-
#id ⇒ String
The unique identifier of the term.
-
#lockout_period ⇒ String
The duration before the agreement end date when the lockout window begins, in ISO 8601 format (for example, P30D).
-
#max_renewals ⇒ Integer
The maximum number of renewals allowed on this offer.
-
#price_increase ⇒ Types::PriceIncrease
The price increase applied at each renewal cycle.
-
#term_templates ⇒ Array<Types::TermTemplate>
Structural templates defining how specific terms are reshaped on each renewal cycle.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#adjustment_deadline ⇒ String
The duration before the agreement end date by which the renewal
price is finalized, represented in ISO 8601 format (for example,
P30D). Only applicable with PercentageRange.
2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452 class RenewalTerm < Struct.new( :id, :type, :max_renewals, :lockout_period, :adjustment_deadline, :price_increase, :term_templates) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452 class RenewalTerm < Struct.new( :id, :type, :max_renewals, :lockout_period, :adjustment_deadline, :price_increase, :term_templates) SENSITIVE = [] include Aws::Structure end |
#lockout_period ⇒ String
The duration before the agreement end date when the lockout window begins, in ISO 8601 format (for example, P30D). Absent means no lockout.
2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452 class RenewalTerm < Struct.new( :id, :type, :max_renewals, :lockout_period, :adjustment_deadline, :price_increase, :term_templates) SENSITIVE = [] include Aws::Structure end |
#max_renewals ⇒ Integer
The maximum number of renewals allowed on this offer. Absent means unlimited renewals.
2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452 class RenewalTerm < Struct.new( :id, :type, :max_renewals, :lockout_period, :adjustment_deadline, :price_increase, :term_templates) SENSITIVE = [] include Aws::Structure end |
#price_increase ⇒ Types::PriceIncrease
The price increase applied at each renewal cycle. Absent means identical pricing on renewal.
2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452 class RenewalTerm < Struct.new( :id, :type, :max_renewals, :lockout_period, :adjustment_deadline, :price_increase, :term_templates) SENSITIVE = [] include Aws::Structure end |
#term_templates ⇒ Array<Types::TermTemplate>
Structural templates defining how specific terms are reshaped on each renewal cycle. Absent for upfront-only offers.
2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452 class RenewalTerm < Struct.new( :id, :type, :max_renewals, :lockout_period, :adjustment_deadline, :price_increase, :term_templates) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2452 class RenewalTerm < Struct.new( :id, :type, :max_renewals, :lockout_period, :adjustment_deadline, :price_increase, :term_templates) SENSITIVE = [] include Aws::Structure end |