Class: Aws::MarketplaceDiscovery::Types::Resource
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::Resource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A resource that provides supplementary information about a product, such as documentation links, support contacts, or usage instructions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
The format of the resource content, such as a URL, email address, or text.
-
#display_name ⇒ String
An optional human-readable label for the resource.
-
#resource_type ⇒ String
The category of the resource, such as manufacturer support or usage instructions.
-
#value ⇒ String
The resource content.
Instance Attribute Details
#content_type ⇒ String
The format of the resource content, such as a URL, email address, or text.
2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2487 class Resource < Struct.new( :resource_type, :content_type, :value, :display_name) SENSITIVE = [] include Aws::Structure end |
#display_name ⇒ String
An optional human-readable label for the resource.
2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2487 class Resource < Struct.new( :resource_type, :content_type, :value, :display_name) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The category of the resource, such as manufacturer support or usage instructions.
2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2487 class Resource < Struct.new( :resource_type, :content_type, :value, :display_name) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The resource content. Interpretation depends on the content type.
2487 2488 2489 2490 2491 2492 2493 2494 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2487 class Resource < Struct.new( :resource_type, :content_type, :value, :display_name) SENSITIVE = [] include Aws::Structure end |