Class: Aws::MarketplaceDiscovery::Types::ReviewSourceSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::ReviewSourceSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
A review summary from a specific source, including the average rating and total review count.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#average_rating ⇒ String
The average rating across all reviews from this source.
-
#source_id ⇒ String
The machine-readable identifier of the review source.
-
#source_name ⇒ String
The name of the review source, such as AWS Marketplace.
-
#source_url ⇒ String
The URL where the reviews can be accessed at the source.
-
#total_reviews ⇒ Integer
The total number of reviews available from this source.
Instance Attribute Details
#average_rating ⇒ String
The average rating across all reviews from this source.
2534 2535 2536 2537 2538 2539 2540 2541 2542 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534 class ReviewSourceSummary < Struct.new( :source_name, :source_id, :source_url, :average_rating, :total_reviews) SENSITIVE = [] include Aws::Structure end |
#source_id ⇒ String
The machine-readable identifier of the review source.
2534 2535 2536 2537 2538 2539 2540 2541 2542 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534 class ReviewSourceSummary < Struct.new( :source_name, :source_id, :source_url, :average_rating, :total_reviews) SENSITIVE = [] include Aws::Structure end |
#source_name ⇒ String
The name of the review source, such as AWS Marketplace.
2534 2535 2536 2537 2538 2539 2540 2541 2542 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534 class ReviewSourceSummary < Struct.new( :source_name, :source_id, :source_url, :average_rating, :total_reviews) SENSITIVE = [] include Aws::Structure end |
#source_url ⇒ String
The URL where the reviews can be accessed at the source.
2534 2535 2536 2537 2538 2539 2540 2541 2542 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534 class ReviewSourceSummary < Struct.new( :source_name, :source_id, :source_url, :average_rating, :total_reviews) SENSITIVE = [] include Aws::Structure end |
#total_reviews ⇒ Integer
The total number of reviews available from this source.
2534 2535 2536 2537 2538 2539 2540 2541 2542 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2534 class ReviewSourceSummary < Struct.new( :source_name, :source_id, :source_url, :average_rating, :total_reviews) SENSITIVE = [] include Aws::Structure end |