Class: Aws::MarketplaceDiscovery::Types::SageMakerModelFulfillmentOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::SageMakerModelFulfillmentOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Describes an Amazon SageMaker model fulfillment option, including version details and recommended instance types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
-
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
-
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
-
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
-
#recommendation ⇒ Types::SageMakerModelRecommendation
Recommended instance types for inference with this model.
-
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
-
#usage_instructions ⇒ String
Instructions on how to use this SageMaker model.
Instance Attribute Details
#fulfillment_option_display_name ⇒ String
A human-readable name for the fulfillment option type.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699 class SageMakerModelFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :release_notes, :usage_instructions, :recommendation) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_id ⇒ String
The unique identifier of the fulfillment option.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699 class SageMakerModelFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :release_notes, :usage_instructions, :recommendation) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_type ⇒ String
The category of the fulfillment option.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699 class SageMakerModelFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :release_notes, :usage_instructions, :recommendation) SENSITIVE = [] include Aws::Structure end |
#fulfillment_option_version ⇒ String
The version identifier of the fulfillment option.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699 class SageMakerModelFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :release_notes, :usage_instructions, :recommendation) SENSITIVE = [] include Aws::Structure end |
#recommendation ⇒ Types::SageMakerModelRecommendation
Recommended instance types for inference with this model.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699 class SageMakerModelFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :release_notes, :usage_instructions, :recommendation) SENSITIVE = [] include Aws::Structure end |
#release_notes ⇒ String
Release notes describing changes in this version of the fulfillment option.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699 class SageMakerModelFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :release_notes, :usage_instructions, :recommendation) SENSITIVE = [] include Aws::Structure end |
#usage_instructions ⇒ String
Instructions on how to use this SageMaker model.
2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2699 class SageMakerModelFulfillmentOption < Struct.new( :fulfillment_option_id, :fulfillment_option_type, :fulfillment_option_display_name, :fulfillment_option_version, :release_notes, :usage_instructions, :recommendation) SENSITIVE = [] include Aws::Structure end |