Class: Aws::MarketplaceDiscovery::Types::SearchFacetsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::SearchFacetsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#facet_types ⇒ Array<String>
A list of specific facet types to retrieve.
-
#filters ⇒ Array<Types::SearchFilter>
Filters to apply before retrieving facets.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#search_text ⇒ String
The search query text to filter listings before retrieving facets.
Instance Attribute Details
#facet_types ⇒ Array<String>
A list of specific facet types to retrieve. If empty or null, all available facets are returned.
2771 2772 2773 2774 2775 2776 2777 2778 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2771 class SearchFacetsInput < Struct.new( :search_text, :filters, :facet_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::SearchFilter>
Filters to apply before retrieving facets. Multiple filters are combined with AND logic. Multiple values within the same filter are combined with OR logic.
2771 2772 2773 2774 2775 2776 2777 2778 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2771 class SearchFacetsInput < Struct.new( :search_text, :filters, :facet_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. Make
the call again using the returned token to retrieve the next page.
2771 2772 2773 2774 2775 2776 2777 2778 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2771 class SearchFacetsInput < Struct.new( :search_text, :filters, :facet_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#search_text ⇒ String
The search query text to filter listings before retrieving facets.
2771 2772 2773 2774 2775 2776 2777 2778 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2771 class SearchFacetsInput < Struct.new( :search_text, :filters, :facet_types, :next_token) SENSITIVE = [] include Aws::Structure end |