Class: Aws::MarketplaceDiscovery::Types::SearchFacetsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::SearchFacetsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#listing_facets ⇒ Hash<String,Array<Types::ListingFacet>>
A map of facet types to their corresponding facet values.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#total_results ⇒ Integer
The total number of listings matching the search criteria.
Instance Attribute Details
#listing_facets ⇒ Hash<String,Array<Types::ListingFacet>>
A map of facet types to their corresponding facet values. Each facet value includes a display name, internal value, and count of matching listings.
2797 2798 2799 2800 2801 2802 2803 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2797 class SearchFacetsOutput < Struct.new( :total_results, :listing_facets, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. Make
the call again using the returned token to retrieve the next page.
2797 2798 2799 2800 2801 2802 2803 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2797 class SearchFacetsOutput < Struct.new( :total_results, :listing_facets, :next_token) SENSITIVE = [] include Aws::Structure end |
#total_results ⇒ Integer
The total number of listings matching the search criteria.
2797 2798 2799 2800 2801 2802 2803 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2797 class SearchFacetsOutput < Struct.new( :total_results, :listing_facets, :next_token) SENSITIVE = [] include Aws::Structure end |