Class: Aws::MarketplaceDiscovery::Types::SellerEngagement
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::SellerEngagement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
An engagement option available to potential buyers of a product, such as requesting a private offer or a demo.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
The format of the engagement value, such as a URL.
-
#engagement_type ⇒ String
The type of engagement, such as
REQUEST_FOR_PRIVATE_OFFERorREQUEST_FOR_DEMO. -
#value ⇒ String
The engagement value, such as a URL to the engagement form.
Instance Attribute Details
#content_type ⇒ String
The format of the engagement value, such as a URL.
2932 2933 2934 2935 2936 2937 2938 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2932 class SellerEngagement < Struct.new( :engagement_type, :content_type, :value) SENSITIVE = [] include Aws::Structure end |
#engagement_type ⇒ String
The type of engagement, such as REQUEST_FOR_PRIVATE_OFFER or
REQUEST_FOR_DEMO.
2932 2933 2934 2935 2936 2937 2938 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2932 class SellerEngagement < Struct.new( :engagement_type, :content_type, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The engagement value, such as a URL to the engagement form.
2932 2933 2934 2935 2936 2937 2938 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2932 class SellerEngagement < Struct.new( :engagement_type, :content_type, :value) SENSITIVE = [] include Aws::Structure end |