Class: Aws::MarketplaceDiscovery::Types::TermTemplate
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::TermTemplate
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Note:
TermTemplate is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TermTemplate corresponding to the set member.
A structural template defining how a specific term type is reshaped on each renewal cycle. Exactly one variant is present.
Defined Under Namespace
Classes: PaymentScheduleTermTemplate, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#payment_schedule_term_template ⇒ Types::PaymentScheduleTermTemplate
The installment schedule used to structure payments on the renewal offer.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#payment_schedule_term_template ⇒ Types::PaymentScheduleTermTemplate
The installment schedule used to structure payments on the renewal offer.
2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2996 class TermTemplate < Struct.new( :payment_schedule_term_template, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class PaymentScheduleTermTemplate < TermTemplate; end class Unknown < TermTemplate; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
2996 2997 2998 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 2996 def unknown @unknown end |