Class: Aws::MarketplaceDiscovery::Types::VariablePaymentTerm
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceDiscovery::Types::VariablePaymentTerm
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacediscovery/types.rb
Overview
Defines a variable payment term with a maximum total charge amount.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
Defines the currency for the prices in this term.
-
#id ⇒ String
The unique identifier of the term.
-
#max_total_charge_amount ⇒ String
The maximum total amount that can be charged under this term.
-
#type ⇒ String
The category of the term.
Instance Attribute Details
#currency_code ⇒ String
Defines the currency for the prices in this term.
3177 3178 3179 3180 3181 3182 3183 3184 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3177 class VariablePaymentTerm < Struct.new( :id, :type, :currency_code, :max_total_charge_amount) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the term.
3177 3178 3179 3180 3181 3182 3183 3184 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3177 class VariablePaymentTerm < Struct.new( :id, :type, :currency_code, :max_total_charge_amount) SENSITIVE = [] include Aws::Structure end |
#max_total_charge_amount ⇒ String
The maximum total amount that can be charged under this term.
3177 3178 3179 3180 3181 3182 3183 3184 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3177 class VariablePaymentTerm < Struct.new( :id, :type, :currency_code, :max_total_charge_amount) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The category of the term.
3177 3178 3179 3180 3181 3182 3183 3184 |
# File 'lib/aws-sdk-marketplacediscovery/types.rb', line 3177 class VariablePaymentTerm < Struct.new( :id, :type, :currency_code, :max_total_charge_amount) SENSITIVE = [] include Aws::Structure end |